==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/SourceLocator.h <==
// public class org.dellroad.jc.cgen.SourceLocator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c723c4f9afb88587 org_dellroad_jc_cgen_SourceLocator
// @dep_class be376690108f5fb9 soot_util_SourceLocator

// header file dependencies
// @dep_header soot_util_SourceLocator

#include "soot/util/SourceLocator.h"

#ifndef _JC_org_dellroad_jc_cgen_SourceLocator_H_
#define _JC_org_dellroad_jc_cgen_SourceLocator_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_dellroad_jc_ClassfileFinder$object;
struct _jc_soot_Singletons__24Global$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_SourceLocator$sub_refs	_jc_org_dellroad_jc_cgen_SourceLocator$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_SourceLocator$sub_nonrefs	_jc_org_dellroad_jc_cgen_SourceLocator$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_SourceLocator$refs	_jc_org_dellroad_jc_cgen_SourceLocator$refs;
typedef struct _jc_org_dellroad_jc_cgen_SourceLocator$nonrefs	_jc_org_dellroad_jc_cgen_SourceLocator$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_SourceLocator$object	_jc_org_dellroad_jc_cgen_SourceLocator$object;

typedef const struct _jc_org_dellroad_jc_cgen_SourceLocator$vmethods	_jc_org_dellroad_jc_cgen_SourceLocator$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_SourceLocator$vtable	_jc_org_dellroad_jc_cgen_SourceLocator$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_SourceLocator$vtype	_jc_org_dellroad_jc_cgen_SourceLocator$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_SourceLocator$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_org_dellroad_jc_cgen_SourceLocator$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern struct _jc_java_io_InputStream$object *_jc_org_dellroad_jc_cgen_SourceLocator$method$getInputStreamOf$3620343256421670(_jc_env *, struct _jc_org_dellroad_jc_cgen_SourceLocator$object *, struct _jc_java_lang_String$object *);
extern void _jc_org_dellroad_jc_cgen_SourceLocator$method$setFinder$0429307cdfcab518(_jc_env *, struct _jc_org_dellroad_jc_cgen_SourceLocator$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_SourceLocator$method_info$getInputStreamOf$3620343256421670;
extern _jc_method _jc_org_dellroad_jc_cgen_SourceLocator$method_info$setFinder$0429307cdfcab518;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_SourceLocator$vmethods {
	struct _jc_java_io_InputStream$object	*(*getInputStreamOf$3620343256421670)(_jc_env *, struct _jc_org_dellroad_jc_cgen_SourceLocator$object *, struct _jc_java_lang_String$object *);
	void	(*setFinder$0429307cdfcab518)(_jc_env *, struct _jc_org_dellroad_jc_cgen_SourceLocator$object *, struct _jc_object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_SourceLocator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_SourceLocator$vmethods	soot_util_SourceLocator;
	_jc_org_dellroad_jc_cgen_SourceLocator$vmethods	org_dellroad_jc_cgen_SourceLocator;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_SourceLocator$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_SourceLocator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_SourceLocator$sub_refs {
	struct _jc_object	*finder;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_SourceLocator$refs {
    _jc_org_dellroad_jc_cgen_SourceLocator$sub_refs	org_dellroad_jc_cgen_SourceLocator;
    _jc_soot_util_SourceLocator$sub_refs	soot_util_SourceLocator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_SourceLocator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_SourceLocator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_SourceLocator$sub_nonrefs	soot_util_SourceLocator;
    _jc_org_dellroad_jc_cgen_SourceLocator$sub_nonrefs	org_dellroad_jc_cgen_SourceLocator;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_SourceLocator$object {
	_jc_org_dellroad_jc_cgen_SourceLocator$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_SourceLocator$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_SourceLocator$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_SourceLocator$vtype _jc_org_dellroad_jc_cgen_SourceLocator$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_SourceLocator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_SourceLocator$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_SourceLocator_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/SourceLocator.h <==
// public class org.dellroad.jc.cgen.SourceLocator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c723c4f9afb88587 org_dellroad_jc_cgen_SourceLocator
// @dep_class be376690108f5fb9 soot_util_SourceLocator

// header file dependencies
// @dep_header soot_util_SourceLocator

#include "soot/util/SourceLocator.h"

#ifndef _JC_org_dellroad_jc_cgen_SourceLocator_H_
#define _JC_org_dellroad_jc_cgen_SourceLocator_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_dellroad_jc_ClassfileFinder$object;
struct _jc_soot_Singletons__24Global$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_SourceLocator$sub_refs	_jc_org_dellroad_jc_cgen_SourceLocator$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_SourceLocator$sub_nonrefs	_jc_org_dellroad_jc_cgen_SourceLocator$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_SourceLocator$refs	_jc_org_dellroad_jc_cgen_SourceLocator$refs;
typedef struct _jc_org_dellroad_jc_cgen_SourceLocator$nonrefs	_jc_org_dellroad_jc_cgen_SourceLocator$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_SourceLocator$object	_jc_org_dellroad_jc_cgen_SourceLocator$object;

typedef const struct _jc_org_dellroad_jc_cgen_SourceLocator$vmethods	_jc_org_dellroad_jc_cgen_SourceLocator$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_SourceLocator$vtable	_jc_org_dellroad_jc_cgen_SourceLocator$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_SourceLocator$vtype	_jc_org_dellroad_jc_cgen_SourceLocator$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_SourceLocator$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_org_dellroad_jc_cgen_SourceLocator$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_io_InputStream$object *_jc_org_dellroad_jc_cgen_SourceLocator$method$getInputStreamOf$3620343256421670(_jc_env *, struct _jc_org_dellroad_jc_cgen_SourceLocator$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_SourceLocator$method$setFinder$0429307cdfcab518(_jc_env *, struct _jc_org_dellroad_jc_cgen_SourceLocator$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_SourceLocator$method_info$getInputStreamOf$3620343256421670;
extern _jc_method _jc_org_dellroad_jc_cgen_SourceLocator$method_info$setFinder$0429307cdfcab518;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_SourceLocator$vmethods {
	struct _jc_java_io_InputStream$object	*(*getInputStreamOf$3620343256421670)(_jc_env *, struct _jc_org_dellroad_jc_cgen_SourceLocator$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*setFinder$0429307cdfcab518)(_jc_env *, struct _jc_org_dellroad_jc_cgen_SourceLocator$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_SourceLocator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_SourceLocator$vmethods	soot_util_SourceLocator;
	_jc_org_dellroad_jc_cgen_SourceLocator$vmethods	org_dellroad_jc_cgen_SourceLocator;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_SourceLocator$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_SourceLocator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_SourceLocator$sub_refs {
	struct _jc_object	*finder;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_SourceLocator$refs {
    _jc_org_dellroad_jc_cgen_SourceLocator$sub_refs	org_dellroad_jc_cgen_SourceLocator;
    _jc_soot_util_SourceLocator$sub_refs	soot_util_SourceLocator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_SourceLocator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_SourceLocator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_SourceLocator$sub_nonrefs	soot_util_SourceLocator;
    _jc_org_dellroad_jc_cgen_SourceLocator$sub_nonrefs	org_dellroad_jc_cgen_SourceLocator;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_SourceLocator$object {
	_jc_org_dellroad_jc_cgen_SourceLocator$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_SourceLocator$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_SourceLocator$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_SourceLocator$vtype _jc_org_dellroad_jc_cgen_SourceLocator$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_SourceLocator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_SourceLocator$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_SourceLocator_H_ */
